@@ -5,8 +5,10 @@ import os
 
 from future.moves import subprocess
 
+from sagify.log import logger
 
-def train(dir):
+
+def train(dir, docker_tag):
     """
     Trains ML model(s) locally
 
@@ -19,15 +21,17 @@ def train(dir):
     if not os.path.isdir(test_path):
         raise ValueError("This is not a sagify directory: {}".format(dir))
 
-    subprocess.check_output(
+    output = subprocess.check_output(
         [
             "{}".format(local_train_script_path),
-            "{}".format(os.path.abspath(test_path))
+            "{}".format(os.path.abspath(test_path)),
+            docker_tag
         ]
     )
+    logger.debug(output)
 
 
-def deploy(dir):
+def deploy(dir, docker_tag):
     """
     Deploys ML models(s) locally
 
@@ -40,9 +44,11 @@ def deploy(dir):
     if not os.path.isdir(test_path):
         raise ValueError("This is not a sagify directory: {}".format(dir))
 
-    subprocess.check_output(
+    output = subprocess.check_output(
         [
             "{}".format(local_deploy_script_path),
-            "{}".format(os.path.abspath(test_path))
+            "{}".format(os.path.abspath(test_path)),
+            docker_tag
         ]
     )
+    logger.debug(output)
