@@ -2,5 +2,6 @@
 
 image={{ cookiecutter.project_slug }}-img
 test_path=$1
+tag=$2
 
-docker run -v ${test_path}:/opt/ml --rm ${image} train
+docker run -v ${test_path}:/opt/ml --rm "${image}:${tag}" train
